@@ -3,10 +3,10 @@ import copy
 from botocore.args import ClientArgsCreator
 import botocore.serialize
 import botocore.parsers
-from botocore.signers import RequestSigner
 
 from .config import AioConfig
 from .endpoint import AioEndpointCreator
+from .signers import AioRequestSigner
 
 
 class AioClientArgsCreator(ClientArgsCreator):
@@ -32,7 +32,7 @@ class AioClientArgsCreator(ClientArgsCreator):
         endpoint_region_name = endpoint_config['region_name']
 
         event_emitter = copy.copy(self._event_emitter)
-        signer = RequestSigner(
+        signer = AioRequestSigner(
             service_model.service_id, signing_region,
             endpoint_config['signing_name'],
             endpoint_config['signature_version'],
