@@ -70,12 +70,21 @@ class AioClientCreator(ClientCreator):
 
 
 class AioBaseClient(BaseClient):
-    def __getattr__(self, item):
-        # TODO: this is not supported yet as emit_until_response is an async function
-        raise AttributeError(
-            "'%s' object has no attribute '%s'" % (
-                self.__class__.__name__, item)
+    async def _async_getattr(self, item):
+        event_name = 'getattr.%s.%s' % (
+            self._service_model.service_id.hyphenize(), item
         )
+        handler, event_response = await self.meta.events.emit_until_response(
+            event_name, client=self)
+
+        return event_response
+
+    def __getattr__(self, item):
+        # NOTE: we can not reliably support this because if we were to make this a
+        # deferred attrgetter (See #803), it would resolve in hasattr always returning
+        # true.  This ends up breaking ddtrace for example when it tries to set a pin.
+        raise AttributeError(
+            "'%s' object has no attribute '%s'" % (self.__class__.__name__, item))
 
     async def _make_api_call(self, operation_name, api_params):
         operation_model = self._service_model.operation_model(operation_name)
